# Contributing

## Ideas and more!

1. Read the code of conduct below
1. Join the mailing list at <https://groups.io/g/swarm-dev>
1. Join a meeting at <https://hackmd.io/@swarm/meetings>
1. Found something to improve? [Open an Issue on GitHub](https://github.com/Swarm-DISC/SwarmPAL/issues) or get in touch otherwise
1. Have other ideas / requests for help? [Start a Discussion on GitHub](https://github.com/Swarm-DISC/SwarmPAL/discussions)

## Development

1. Read the development guide at [https://hackmd.io/@swarm/dev](https://hackmd.io/@swarm/dev/%2FVFOe2P1ETYmup0K0YSxKEQ?view)
1. Open an Issue/PR ☺️

---

```{include} ../CODE_OF_CONDUCT.md
```
